LevelsPicker<T extends LevelsBaseModel> class

Inheritance

Constructors

LevelsPicker({Key? key, List<T> items = const [], double height = 320, double headerHeight = 48, double sectionHeight = 44, double pageHeight = 200, ShowLevelType levelStepStype = ShowLevelType.showLevels, ShowPickExtendsUI levelExtendsUI = ShowPickExtendsUI.extendsNone, int maxLevel = 0, ValueChanged? callBack, VoidCallback? warningCallBack, String warningStr = '', bool editStatus = false, List<T> cacheItems = const [], List<List<T>> cachePageItems = const [], bool isAutoClose = true, WidgetBuilder? builderHeader, bool hideHeader = false, Decoration? headerDecoration, Widget? title, Widget? cancel, String cancelText = '', TextStyle? cancelTextStyle, Widget? confirm, String confirmText = '', TextStyle? confirmTextStyle, Color? headerColor, double itemExtent = 0.0, TextStyle? textStyle, TextStyle? selectedTextStyle, VoidCallback? onCancel, PickerConfirmCallback? onConfirm, PickerConfirmBeforeCallback? onConfirmBefore, PickerSelectedCallback? onSelect, Widget? builderFooter, bool hideFooter = true, bool isCircleCorner = false, required PickerLevelAdapter<T> adapter})

Properties

adapter → PickerLevelAdapter<T>
final
builderFooter → Widget?
final
builderHeader → WidgetBuilder?
final
cacheItems → List<T>
final
cachePageItems → List<List<T>>
final
callBack → ValueChanged?
final
cancel → Widget?
final
cancelText → String
final
cancelTextStyle → TextStyle?
final
confirm → Widget?
final
confirmText → String
final
confirmTextStyle → TextStyle?
final
editStatus → bool
final
hashCode → int
The hash code for this object.
no setterinherited
headerColor → Color?
final
headerDecoration → Decoration?
final
headerHeight → double
final
height → double
final
hideFooter → bool
final
hideHeader → bool
final
isAutoClose → bool
final
isCircleCorner → bool
final
itemExtent → double
Height of list item
final
items → List<T>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
levelExtendsUI → ShowPickExtendsUI
final
levelStepStype → ShowLevelType
final
maxLevel → int
final
onCancel → VoidCallback?
final
onConfirm → PickerConfirmCallback?
final
onConfirmBefore → PickerConfirmBeforeCallback?
final
onSelect → PickerSelectedCallback?
final
pageHeight → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionHeight → double
final
selectedTextStyle → TextStyle?
final
textStyle → TextStyle?
final
title → Widget?
final
warningCallBack → VoidCallback?
final
warningStr → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CityPickerState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited