PickerAnyAdapter<T> class

Inheritance

Constructors

PickerAnyAdapter({String title = '', Image? icon, IconButton? btn, List<T> items = const [], int maxLevel = 0, ShowPickExtendsUI levelExtendsUI = ShowPickExtendsUI.extendsNone, Text? extendLabel, String placeHolderText = '子分类'})

Properties

btn → IconButton?
final
callBack ↔ AdapterItemCallBack?
getter/setter pairinherited
extendLabel → Text?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Image?
final
items → List<T>
final
levelExtendsUI → ShowPickExtendsUI
final
maxLevel → int
final
placeHolderText → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

buildItem(BuildContext context, int index, LevelsBaseModel item) → Widget
override
getExtendUI(LevelsBaseModel item) → Widget
getLength() → int
override
getMaxLevel() → int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited